<?php
// MYSQL SERVER CONFIG WIZARD
//
// Copyright (c) 2010 Nagios Enterprises, LLC.  All rights reserved.
//  
// $Id: $

include_once(dirname(__FILE__).'/../configwizardhelper.inc.php');

// run the initialization function
oracletablespace_configwizard_init();

function oracletablespace_configwizard_init(){

	$name="oracletablespace";
	
	$args=array(
		CONFIGWIZARD_NAME => $name,
        CONFIGWIZARD_VERSION => "1.5",
		CONFIGWIZARD_TYPE => CONFIGWIZARD_TYPE_MONITORING,
		CONFIGWIZARD_DESCRIPTION => gettext("Monitor an Oracle Tablespace"),
		CONFIGWIZARD_DISPLAYTITLE => gettext("Oracle Tablespace"),
		CONFIGWIZARD_FUNCTION => "oracletablespace_configwizard_func",
		CONFIGWIZARD_PREVIEWIMAGE => "oracletablespace.png",
		);
		
	register_configwizard($name,$args);
	}



function oracletablespace_configwizard_func($mode="",$inargs=null,&$outargs,&$result){

	$wizard_name="oracletablespace";
	
	// initialize return code and output
	$result=0;
	$output="";
	
	// initialize output args - pass back the same data we got
	$outargs[CONFIGWIZARD_PASSBACK_DATA]=$inargs;


	switch($mode){
		case CONFIGWIZARD_MODE_GETSTAGE1HTML:
		
			$address=grab_array_var($inargs,"address","");
			$port=grab_array_var($inargs,"port","1521");
            $sid=grab_array_var($inargs,"sid","");
			$username=grab_array_var($inargs,"username","");
			$password=grab_array_var($inargs,"password","");
			$database=grab_array_var($inargs,"database","SYSTEM");

			//sanity check for wizard requirements
			$sanity=''; 
			if( (!file_exists('/usr/lib/oracle') && !file_exists('/usr/lib64/oracle')) ||  
                 !file_exists('/usr/local/nagios/libexec/check_oracle_health')) {
				$sanity.="<div style='color:red'><strong>".gettext('WARNING:')."</strong> O".gettext('racle libraries do not appear to be installed. See the')." 
				<a href='http://assets.nagios.com/downloads/nagiosxi/docs/Oracle_Plugin_Installation.pdf' title='Install Instructions' target='_blank'>
				".gettext('Oracle Plugin Installation')."</a> ".gettext('instructions for monitoring Oracle')."</div>\n"; 
			}
			
			$output='

	<div class="sectionTitle">Oracle Tablespace</div>
	'.$sanity.'
	<p>
	'.gettext('Specify the details for connecting to the Oracle tablespace you want to monitor.').'
	</p>
			
	<table>

	<tr>
	<td valign="top">
	<label>'.gettext('Address').':</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="40" name="address" id="address" value="'.htmlentities($address).'" class="textfield" /><br class="nobr" />
	'.gettext('The IP address or FQDNS name of the Oracle server.').'<br><br>
	</td>
	</tr>
	
	<tr>
	<td valign="top">
	<label>'.gettext('Port').':</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="5" name="port" id="port" value="'.htmlentities($port).'" class="textfield" /><br class="nobr" />
	'.gettext('The port to use to connect to the Oracle server.').'<br><br>
	</td>
	</tr>
    
	<tr>
	<td valign="top">
	<label>'.gettext('SID').':</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="5" name="sid" id="sid" value="'.htmlentities($sid).'" class="textfield" /><br class="nobr" />
	'.gettext('The SID to use to connect to the Oracle server.').'<br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<label>'.gettext('Username:').'</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="20" name="username" id="username" value="'.htmlentities($username).'" class="textfield" /><br class="nobr" />
	'.gettext('The username used to connect to the Oracle server.').'<br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<label>'.gettext('Password:').'</label><br class="nobr" />
	</td>
	<td>
<input type="password" size="20" name="password" id="password" value="'.htmlentities($password).'" class="textfield" /><br class="nobr" />
	'.gettext('The password used to connect to the Oracle server.').'<br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<label>'.gettext('Database:').'</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="20" name="database" id="database" value="'.htmlentities($database).'" class="textfield" /><br class="nobr" />
	'.gettext('The tablespace to connect to on the Oracle server.').'<br><br>
	</td>
	</tr>


	</table>

			';
			break;
			
		case CONFIGWIZARD_MODE_VALIDATESTAGE1DATA:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address","");
			$port=grab_array_var($inargs,"port","");
			$username=grab_array_var($inargs,"username","");
			$password=grab_array_var($inargs,"password","");
			$database=grab_array_var($inargs,"database","");
            $sid=grab_array_var($inargs,"sid","");
			
			// check for errors
			$errors=0;
			$errmsg=array();
			if(have_value($address)==false)
				$errmsg[$errors++]=gettext("No address specified.");
			if(have_value($port)==false)
				$errmsg[$errors++]=gettext("No port number specified.");				
			if(have_value($username)==false)
				$errmsg[$errors++]=gettext("No username specified.");
			if(have_value($password)==false)
				$errmsg[$errors++]=gettext("No password specified.");
			if(have_value($database)==false)
				$errmsg[$errors++]=gettext("No tablespace specified.");
				
			if($errors>0){
				$outargs[CONFIGWIZARD_ERROR_MESSAGES]=$errmsg;
				$result=1;
				}
				
			break;
			
		case CONFIGWIZARD_MODE_GETSTAGE2HTML:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address");
			$port=grab_array_var($inargs,"port","");
			$username=grab_array_var($inargs,"username","");
			$password=grab_array_var($inargs,"password","");
			$database=grab_array_var($inargs,"database","");
            $sid=grab_array_var($inargs,"sid","");

			$ha=@gethostbyaddr($address);
			if($ha=="")
				$ha=$address;
			$hostname=grab_array_var($inargs,"hostname",$ha);
			
		
			$services=grab_array_var($inargs,"services",array(
				"usage"=>"on",
				"free"=>"on",
				"remaining-time" => "on",
				"fragmentation"=>"on",
				"io-balance"=>"on",
				"can-allocate-next"=>"on",
				));
			$serviceargs=grab_array_var($inargs,"serviceargs",array(
				"usage_warning"=>"90",
				"usage_critical"=>"98",
				"free_warning"=>"5:",
				"free_critical"=>"2:",
				"remaining-time_warning"=>"10",
				"remaining-time_critical"=>"20",
				"fragmentation_warning"=>"30:",
				"fragmentation_critical"=>"20:",
				"io-balance_warning"=>"50",
				"io-balance_critical"=>"100",
				"can-allocate-next_warning"=>"20",
				"can-allocate-next_critical"=>"30",
				));
			
			$services_serial=grab_array_var($inargs,"services_serial");
			if($services_serial!="")
				$services=unserialize(base64_decode($services_serial));
			$serviceargs_serial=grab_array_var($inargs,"serviceargs_serial");
			if($serviceargs_serial!=""){
				//echo "ARGSSERIAL: $serviceargs_serial<BR>\n";
				$serviceargs=unserialize(base64_decode($serviceargs_serial));
				}
		
			$output='
			
		<input type="hidden" name="address" value="'.htmlentities($address).'">
		<input type="hidden" name="port" value="'.htmlentities($port).'">
		<input type="hidden" name="username" value="'.htmlentities($username).'">
		<input type="hidden" name="password" value="'.htmlentities($password).'">
		<input type="hidden" name="database" value="'.htmlentities($database).'">
        <input type="hidden" name="sid" value="'.htmlentities($sid).'">

	<div class="sectionTitle">Oracle Server</div>
	
			
	<table>
	
	<tr>
	<td valign="top">
	<label>'.gettext('Address:').'</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="20" name="address" id="address" value="'.htmlentities($address).'" class="textfield" disabled/><br class="nobr" />
	</td>
	</tr>

	<tr>
	<td valign="top">
	<label>'.gettext('Host Name:').'</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="20" name="hostname" id="hostname" value="'.htmlentities($hostname).'" class="textfield" /><br class="nobr" />
	'.gettext('The name you\'d like to have associated with this Oracle Tablespace.').'
	</td>
	</tr>
	
	<tr>
	<td valign="top">
	<label>'.gettext('Port:').'</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="5" name="port" id="port" value="'.htmlentities($port).'" class="textfield" disabled/><br class="nobr" />
	</td>
	</tr>
    
	<tr>
	<td valign="top">
	<label>'.gettext('SID:').'</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="5" name="sid" id="sid" value="'.htmlentities($sid).'" class="textfield" disabled/><br class="nobr" />
	</td>
	</tr>

	<tr>
	<td valign="top">
	<label>'.gettext('Username:').'</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="20" name="username" id="username" value="'.htmlentities($username).'" class="textfield" disabled/><br class="nobr" />
	</td>
	</tr>

	<tr>
	<td valign="top">
	<label>'.gettext('Password:').'</label><br class="nobr" />
	</td>
	<td>
<input type="password" size="20" name="password" id="password" value="'.htmlentities($password).'" class="textfield" disabled/><br class="nobr" />
	</td>
	</tr>

	<tr>
	<td valign="top">
	<label>'.gettext('Tablespace:').'</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="20" name="database" id="database" value="'.htmlentities($database).'" class="textfield" disabled/><br class="nobr" />
	</td>
	</tr>

	</table>


	<div class="sectionTitle">'.gettext('Oracle Tablespace Metrics').'</div>
	
	<p>'.gettext('Specify the metrics you\'d like to monitor on the Oracle Tablespace.').'</p>
	
	
	<table>
	
	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[usage]" '.is_checked(grab_array_var($services,"usage"),"on").'>
	</td>
	<td>
	<b>'.gettext('Tablespace Usage').'</b><br> 
	'.gettext('Monitor amount of space used on the tablespace.').'<br>
	<label>'.gettext('Warning Threshold:').'</label> <input type="text" size="1" name="serviceargs[usage_warning]" value="'.htmlentities($serviceargs["usage_warning"]).'">&nbsp;&nbsp;<label>'.gettext('Critical Threshold:').'</label> <input type="text" size="1" name="serviceargs[usage_critical]" value="'.htmlentities($serviceargs["usage_critical"]).'"><br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[free]" '.is_checked(grab_array_var($services,"free"),"on").'>
	</td>
	<td>
	<b>'.gettext('Tablespace Free Space').'</b><br> 
	'.gettext('Monitor amount of space free on the tablespace.').'<br>
	<label>'.gettext('Warning Threshold:').'</label> <input type="text" size="1" name="serviceargs[free_warning]" value="'.htmlentities($serviceargs["free_warning"]).'">&nbsp;&nbsp;<label>'.gettext('Critical Threshold:').'</label> <input type="text" size="1" name="serviceargs[free_critical]" value="'.htmlentities($serviceargs["free_critical"]).'"><br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[remaining-time]" '.is_checked(grab_array_var($services,"remaining-time"),"on").'>
	</td>
	<td>
	<b>'.gettext('Tablespace Remaining Time Until Full').'</b><br> 
	'.gettext('Monitor indicators of how much time until tablespace is full.').'<br>
	<label>'.gettext('Warning Threshold:').'</label> <input type="text" size="1" name="serviceargs[remaining-time_warning]" value="'.htmlentities($serviceargs["remaining-time_warning"]).'">&nbsp;&nbsp;<label>'.gettext('Critical Threshold:').'</label> <input type="text" size="1" name="serviceargs[remaining-time_critical]" value="'.htmlentities($serviceargs["remaining-time_critical"]).'"><br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[fragmentation]" '.is_checked(grab_array_var($services,"fragmentation"),"on").'>
	</td>
	<td>
	<b>'.gettext('Tablespace Fragmentation').'</b><br> 
	'.gettext('Monitor indicators of how fragmented a tablespace is.').'<br>
	<label>'.gettext('Warning Threshold:').'</label> <input type="text" size="1" name="serviceargs[fragmentation_warning]" value="'.htmlentities($serviceargs["fragmentation_warning"]).'">&nbsp;&nbsp;<label>'.gettext('Critical Threshold:').'</label> <input type="text" size="1" name="serviceargs[fragmentation_critical]" value="'.htmlentities($serviceargs["fragmentation_critical"]).'"><br><br>
	</td>
	</tr>
	
	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[io-balance]" '.is_checked(grab_array_var($services,"io-balance"),"on").'>
	</td>
	<td>
	<b>'.gettext('Tablespace IO Balance').'</b><br> 
	'.gettext('Monitor indicators IO Balance.').'<br>
	<label>'.gettext('Warning Threshold:').'</label> <input type="text" size="1" name="serviceargs[io-balance_warning]" value="'.htmlentities($serviceargs["io-balance_warning"]).'">&nbsp;&nbsp;<label>'.gettext('Critical Threshold:').'</label> <input type="text" size="1" name="serviceargs[io-balance_critical]" value="'.htmlentities($serviceargs["io-balance_critical"]).'"><br><br>
	</td>
	</tr>
	
	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[can-allocate-next]" '.is_checked(grab_array_var($services,"can-allocate-next"),"on").'>
	</td>
	<td>
	<b>'.gettext('Can Allocate Next Extent').'</b><br> 
	'.gettext('Monitor segments of a tablespace which can allocate next extent.').'<br>
	<label>'.gettext('Warning Threshold:').'</label> <input type="text" size="1" name="serviceargs[can-allocate-next_warning]" value="'.htmlentities($serviceargs["can-allocate-next_warning"]).'">&nbsp;&nbsp;<label>'.gettext('Critical Threshold:').'</label> <input type="text" size="1" name="serviceargs[can-allocate-next_critical]" value="'.htmlentities($serviceargs["can-allocate-next_critical"]).'"><br><br>
	</td>
	</tr>
	</table>';
			break;
			
		case CONFIGWIZARD_MODE_VALIDATESTAGE2DATA:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address");
			$hostname=grab_array_var($inargs,"hostname");
			$port=grab_array_var($inargs,"port","");
			$username=grab_array_var($inargs,"username","");
			$password=grab_array_var($inargs,"password","");
			$database=grab_array_var($inargs,"database","");
				
			$services=grab_array_var($inargs,"services",array());
			$serviceargs=grab_array_var($inargs,"serviceargs",array());
			
		
			// check for errors
			$errors=0;
			$errmsg=array();
			if(is_valid_host_name($hostname)==false)
				$errmsg[$errors++]="Invalid host name.";
				
			if($errors>0){
				$outargs[CONFIGWIZARD_ERROR_MESSAGES]=$errmsg;
				$result=1;
				}
				
			break;

			
		case CONFIGWIZARD_MODE_GETSTAGE3HTML:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address");
			$hostname=grab_array_var($inargs,"hostname");
			$port=grab_array_var($inargs,"port","");
			$username=grab_array_var($inargs,"username","");
			$password=grab_array_var($inargs,"password","");
			$database=grab_array_var($inargs,"database","");
            $sid=grab_array_var($inargs,"sid","");
			
			$services=grab_array_var($inargs,"services");
			$serviceargs=grab_array_var($inargs,"serviceargs");
		
			$output='
			
		<input type="hidden" name="address" value="'.htmlentities($address).'">
		<input type="hidden" name="hostname" value="'.htmlentities($hostname).'">
		<input type="hidden" name="port" value="'.htmlentities($port).'">
		<input type="hidden" name="username" value="'.htmlentities($username).'">
		<input type="hidden" name="password" value="'.htmlentities($password).'">
		<input type="hidden" name="database" value="'.htmlentities($database).'">
        <input type="hidden" name="sid" value="'.htmlentities($sid).'">
		<input type="hidden" name="services_serial" value="'.base64_encode(serialize($services)).'">
		<input type="hidden" name="serviceargs_serial" value="'.base64_encode(serialize($serviceargs)).'">
        
		
		<!--SERVICES='.serialize($services).'<BR>
		SERVICEARGS='.serialize($serviceargs).'<BR>-->
		
			';
			break;
			
		case CONFIGWIZARD_MODE_VALIDATESTAGE3DATA:
				
			break;
			
		case CONFIGWIZARD_MODE_GETFINALSTAGEHTML:
			
			
			$output='
			';
			break;
			
		case CONFIGWIZARD_MODE_GETOBJECTS:
		
			$hostname=grab_array_var($inargs,"hostname","");
			$address=grab_array_var($inargs,"address","");
			$hostaddress=$address;
			$port=grab_array_var($inargs,"port","");
            $sid=grab_array_var($inargs,"sid","");
			$username=grab_array_var($inargs,"username","");
			$password=grab_array_var($inargs,"password","");
			$database=grab_array_var($inargs,"database","");
		
			$services_serial=grab_array_var($inargs,"services_serial","");
			$serviceargs_serial=grab_array_var($inargs,"serviceargs_serial","");
			
			$services=unserialize(base64_decode($services_serial));
			$serviceargs=unserialize(base64_decode($serviceargs_serial));
			
			/*
			echo "SERVICES<BR>";
			print_r($services);
			echo "<BR>";
			echo "SERVICEARGS<BR>";
			print_r($serviceargs);
			echo "<BR>";
			*/
			
			// save data for later use in re-entrance
			$meta_arr=array();
			$meta_arr["hostname"]=$hostname;
			$meta_arr["address"]=$address;
			$meta_arr["port"]=$port;
			$meta_arr["username"]=$username;
            $meta_arr["sid"]=$sid;
			$meta_arr["password"]=$password;
			$meta_arr["database"]=$database;
			$meta_arr["services"]=$services;
			$meta_arr["serviceargs"]=$serviceargs;
			save_configwizard_object_meta($wizard_name,$hostname,"",$meta_arr);			
			
			$objs=array();
			
			if(!host_exists($hostname)){
				$objs[]=array(
					"type" => OBJECTTYPE_HOST,
					"use" => "xiwizard_oracletablespace_host",
					"host_name" => $hostname,
					"address" => $hostaddress,
					"icon_image" => "oracle.png",
					"statusmap_image" => "oracle.png",
					"_xiwizard" => $wizard_name,
					);
				}
			
			// common plugin opts
			if(have_value($sid)==false) {
                $commonopts="--connect '{$address}:{$port}' --username '{$username}' --password '{$password}' ";
            }
            else {
                $commonopts="--connect '{$address}:{$port}/{$sid}' --username '{$username}' --password '{$password}' ";
            }
            
			foreach($services as $svcvar => $svcval){
			
				$pluginopts="";
				$pluginopts.=$commonopts;
			
				switch($svcvar){
								
					case "usage":
					
						$pluginopts.="--mode tablespace-usage  --warning ".$serviceargs["usage_warning"]." --critical ".$serviceargs["usage_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "Tablespace Usage",
							"use" => "xiwizard_oracletablespace_service",
							"check_command" => "check_xi_oracletablespace!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;
								
					case "free":
					
						$pluginopts.="--mode tablespace-free  --warning ".$serviceargs["free_warning"]." --critical ".$serviceargs["free_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "Tablespace Free Space",
							"use" => "xiwizard_oracletablespace_service",
							"check_command" => "check_xi_oracletablespace!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;
								
					case "remaining-time":
					
						$pluginopts.="--mode tablespace-remaining-time  --warning ".$serviceargs["remaining-time_warning"]." --critical ".$serviceargs["remaining-time_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "Tablespace Remaining Time",
							"use" => "xiwizard_oracletablespace_service",
							"check_command" => "check_xi_oracletablespace!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;
						
					case "fragmentation":
					
						$pluginopts.="--mode tablespace-fragmentation  --warning ".$serviceargs["fragmentation_warning"]." --critical ".$serviceargs["fragmentation_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "Tablespace Fragmentation",
							"use" => "xiwizard_oracletablespace_service",
							"check_command" => "check_xi_oracletablespace!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;				
						

					case "io-balance":
					
						$pluginopts.="--mode tablespace-io-balance  --warning ".$serviceargs["io-balance_warning"]." --critical ".$serviceargs["io-balance_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "Tablespace IO Balance",
							"use" => "xiwizard_oracletablespace_service",
							"check_command" => "check_xi_oracletablespace!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;	
						
					case "can-allocate-next":
					
						$pluginopts.="--mode tablespace-can-allocate-next  --warning ".$serviceargs["can-allocate-next_warning"]." --critical ".$serviceargs["can-allocate-next_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "Tablespace Can Allocate Next",
							"use" => "xiwizard_oracletablespace_service",
							"check_command" => "check_xi_oracletablespace!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;	
					
					default:
						break;
					}
				}
				
			//echo "OBJECTS:<BR>";
			//print_r($objs);
			//exit();
					
			// return the object definitions to the wizard
			$outargs[CONFIGWIZARD_NAGIOS_OBJECTS]=$objs;
		
			break;
			
		default:
			break;			
		}
		
	return $output;
	}
	

?>